# -*- coding: utf-8 -*-
# Copyright 2021 Red Hat
# GNU General Public License v3.0+
# (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)

from __future__ import absolute_import, division, print_function

__metaclass__ = type

"""
The Interfaces parser templates file. This contains
a list of parser definitions and associated functions that
facilitates both facts gathering and native command generation for
the given network resource.
"""

import re
from ansible_collections.ansible.netcommon.plugins.module_utils.network.common.rm_base.network_template import (
    NetworkTemplate,
)


class InterfacesTemplate(NetworkTemplate):
    def __init__(self, lines=None, module=None):
        super(InterfacesTemplate, self).__init__(
            lines=lines, tmplt=self, module=module
        )

    # fmt: off
    PARSERS = [
        {
            "name": "port",
            "getval": re.compile(
                r"""
                port(\s(?P<port>\S+))
                $""", re.VERBOSE),
            "result": {
                "port": "{{ port }}",
            },
        },
        {
            "name": "duplex",
            "getval": re.compile(
                r"""
                \sduplex(\s(?P<duplex>\S+))
                $""", re.VERBOSE),
            "result": {
                "duplex": "{{ duplex }}",
            },
        },
        {
            "name": "mdix",
            "getval": re.compile(
                r"""
                \smdix(\s(?P<mdix>\S+))\s
                $""", re.VERBOSE),
            "result": {
                "mdix": "{{ mdix }}",
            },
        },
        {
            "name": "description",
            "getval": re.compile(
                r"""
                \sdescription(\s(?P<description>.+))
                $""", re.VERBOSE),
            "result": {
                "description": "{{ description }}",
            },
        },
        {
            "name": "speed",
            "getval": re.compile(
                r"""
                \sspeed
                (\s(?P<com_speed>\S+))
                ((\s(?P<cluded>master|slave))|
                (\s(?P<speed_list>(\d+[,|\s])*\S+)))?
                $""", re.VERBOSE),
            "result": {
                "speed": {
                    "com_speed": "{{ com_speed }}",
                    "1000": "{{ cluded }}",
                    "auto": "{{ speed_list }}",
                },
            },
        },
        {
            "name": "speed.auto_downgrade",
            "getval": re.compile(
                r"""
                \sspeed\sauto-downgrade\s
                $""", re.VERBOSE),
            "result": {
                "speed": {
                    "auto_downgrade": True,
                },
            },
        },
        {
            "name": "shutdown",
            "getval": re.compile(
                r"""\sshutdown
                $""", re.VERBOSE),
            "result": {
                "shutdown": True,
            },
        },
    ]
    # fmt: on
