# -*- coding: utf-8 -*-
# Copyright 2021 Red Hat
# GNU General Public License v3.0+
# (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)

from __future__ import absolute_import, division, print_function

__metaclass__ = type

"""
The Static_routes parser templates file. This contains
a list of parser definitions and associated functions that
facilitates both facts gathering and native command generation for
the given network resource.
"""

import re
from ansible_collections.ansible.netcommon.plugins.module_utils.network.common.rm_base.network_template import (
    NetworkTemplate,
)


class Static_routesTemplate(NetworkTemplate):
    def __init__(self, lines=None, module=None):
        super(Static_routesTemplate, self).__init__(
            lines=lines, tmplt=self, module=module
        )

    # fmt: off
    PARSERS = [
        {
            "name": "ip_route",
            "getval": re.compile(
                r"""
                ^ip\sroute
                (\s(?P<dest>(\d{1,3}\.){3}\d{1,3}/\d+))
                (\s(?P<next_hop>(\d{1,3}\.){3}\d{1,3}))
                (\s(?P<route>primary|backup))
                $""", re.VERBOSE),
            "result": {
                "ip_route": [{
                    "dest": "{{ dest }}",
                    "next_hop": "{{ next_hop }}",
                    "route": "{{ route }}",
                },]
            },
        },
        {
            "name": "ipv6_route",
            "getval": re.compile(
                r"""
                ^ipv6\sroute
                (\s(?P<dest>(([0-9a-fA-F]{0,4}:*)*/\d+)|default))
                (\s(?P<interface_name>\S+))
                (\s(?P<next_hop>([0-9a-fA-F]{0,4}:*)*))
                (\s(?P<route>primary|backup))
                $""", re.VERBOSE),
            "result": {
                "ipv6_route": [{
                    "dest": "{{ '0:0:0:0:0:0:0:0/0' if dest == 'default' else dest }}",
                    "interface_name": "{{ interface_name }}",
                    "next_hop": "{{ next_hop }}",
                    "route": "{{ route }}",
                },]
            },
        },
    ]
    # fmt: on
